@@ -91,11 +91,11 @@ class EventsQueue:
             end_min, end_max = ((None, None)
                                 if ends_equal
                                 else
-                                (event.complement, below_event.complement
-                                if (EventsQueueKey(event.complement)
-                                    < EventsQueueKey(below_event.complement))
-                                else (below_event.complement,
-                                      event.complement)))
+                                ((event.complement, below_event.complement)
+                                 if (EventsQueueKey(event.complement)
+                                     < EventsQueueKey(below_event.complement))
+                                 else (below_event.complement,
+                                       event.complement)))
             if starts_equal:
                 # both line segments are equal or share the left endpoint
                 event.is_overlap = below_event.is_overlap = True
